@@ -24,20 +24,22 @@ dlls = [
     # 'WebView',
     'Positioning',
     'Sensors',
+    'SpatialAudio',
     'Sql',
     'Svg',
+    'TextToSpeech',
     'WebChannel',
     'WebEngineCore',
     'WebEngineWidgets',
     'Widgets',
-    # 'Multimedia',
+    'Multimedia',
+    'MultimediaWidgets',
     'OpenGL',
     'OpenGLWidgets',
     'Quick',
     'QuickWidgets',
     'Qml',
     'QmlModels',
-    # 'MultimediaWidgets',
     'Xml',
     # 'XmlPatterns',
 ]
@@ -56,6 +58,8 @@ QT_PLUGINS = [
     'imageformats',
     'iconengines',
     'tls',
+    'multimedia',
+    'texttospeech',
     # 'mediaservice',
     'platforms',
     # 'playlistformats',
@@ -82,7 +86,8 @@ PYQT_MODULES = (
     'QtCore',
     'QtGui',
     'QtNetwork',
-    # 'QtMultimedia', 'QtMultimediaWidgets',
+    'QtMultimedia', 'QtMultimediaWidgets',
+    'QtTextToSpeech',
     'QtPrintSupport',
     'QtSensors',
     'QtSvg',
